"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_command_1 = require("../../base-command");
const config_file_1 = require("../../lib/config-file");
const prompt_validators_1 = require("../../lib/prompt-validators");
class ConfigInitCommand extends base_command_1.default {
    async run() {
        const configJson = {
            jiraHost: '',
            jiraEmail: '',
            jiraAccessToken: '',
            githubAccessToken: ''
        };
        configJson.jiraHost = await this.promptInput({ message: 'Jira host', default: 'jira.atlassian.com', validator: prompt_validators_1.Validators.required });
        configJson.jiraEmail = await this.promptInput({ message: 'Jira email', validator: prompt_validators_1.Validators.required });
        configJson.jiraAccessToken = await this.promptInput({ message: 'Jira access token (id.atlassian.com/manage/api-tokens)', validator: prompt_validators_1.Validators.required });
        configJson.githubAccessToken = await this.promptInput({ message: 'Github access token (github.com/settings/tokens)', validator: prompt_validators_1.Validators.required });
        const config = new config_file_1.ConfigFile(configJson);
        await this.saveConfig(config);
        this.log(`Saved configuration to ${this.configFilePath}`);
    }
}
ConfigInitCommand.description = 'initialize configuration settings';
exports.default = ConfigInitCommand;
