"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("@oclif/errors");
const axios_1 = require("axios");
class GitHubClient {
    constructor(accessToken) {
        this.accessToken = accessToken;
    }
    async openPullRequest(opts) {
        let repo = opts.repo;
        let title = opts.title;
        let description = opts.description;
        let base = opts.base;
        let draft = opts.draft || false;
        let githubRemote = await this.getGitHubRemote(repo);
        if (!githubRemote) {
            throw new errors_1.CLIError('The current git repo does not have any remotes!');
        }
        let remoteUrl = this.parseGitHubRemoteUrl(githubRemote.url());
        let branch = (await repo.getCurrentBranch()).shorthand();
        let response = await axios_1.default({
            method: 'POST',
            url: `https://api.github.com/repos/${remoteUrl.owner}/${remoteUrl.repo}/pulls`,
            headers: {
                Authorization: `token ${this.accessToken}`,
                Accept: 'application/vnd.github.shadow-cat-preview+json'
            },
            data: {
                title,
                body: description,
                head: branch,
                base,
                draft
            }
        });
        return response.data;
    }
    async getGitHubRemote(repo) {
        const remotes = await this.getGitRemotes(repo);
        return remotes.find((remote) => {
            return remote.url().includes('git@github.com');
        });
    }
    async getGitRemotes(repo) {
        const remotes = await repo.getRemotes();
        const promises = remotes.map((remote) => {
            return repo.getRemote(remote);
        });
        return Promise.all(promises);
    }
    parseGitHubRemoteUrl(url) {
        // GitHub remote url format: git@github.com:owner/repo.git
        const parts = url.split(':')[1].split('/');
        return {
            owner: parts[0],
            repo: parts[1].replace(/.git/, '')
        };
    }
}
exports.GitHubClient = GitHubClient;
